@@ -152,7 +152,7 @@ class AbsolutePath(object):
         if self.op == '//':
             results = []
             results = results + self.relative.resolve(content_node, variables)
-            for child in content_node.children:
+            for child in content_node.get_children():
                 results = results + self.resolve(child, variables)
             return results
         raise Exception("Not implemented")
@@ -182,7 +182,7 @@ class Step(object):
             axis_node = obj
 
             if self.axis == 'parent':
-                axis_node = axis_node.parent
+                axis_node = axis_node.get_parent()
                 if axis_node is None:
                     return []
 
@@ -243,7 +243,7 @@ class AbbreviatedStep(object):
         if self.abbr == '.':
             return [content_node]
         if self.abbr == '..':
-            return [content_node.parent] if content_node.parent else []
+            return [content_node.get_parent()] if content_node.get_parent() else []
         raise Exception("Not implemented")
 
 
@@ -328,6 +328,14 @@ class FunctionCall(object):
             else:
                 return content_node.has_feature(args[0], args[1])
 
+        if self.name == 'hasFeatureValue':
+            values = content_node.get_feature_values(args[0], args[1])
+            if values:
+                for value in values:
+                    if value == args[2]:
+                        return True
+            return False
+
         if self.name == 'content':
             return content_node.content
 
